"""
Generate time series of nominated "gauges" 
Note, this script will only work if pylab is installed on the platform

Inputs:

production dirs: dictionary of production directories with a
                 association to that simulation run, eg high tide,
                 magnitude, etc.
                    
Outputs:

* figures stored in same directory as sww file
* time series data stored in csv files in same directory as sww file
* elevation at nominated gauges (elev_output)
"""

from os import sep
import project
from anuga.abstract_2d_finite_volumes.util import sww2csv_gauges,csv2timeseries_graphs

sww2csv_gauges('slide'+sep+'slidesource.sww',
                project.gauge_filename,
                quantities = ['stage','speed','depth','elevation'],
                verbose=True)
                
sww2csv_gauges('fixed_wave'+sep+'fixed_wavesource.sww',
               project.gauge_filename,
               quantities = ['stage', 'speed','depth','elevation'],
               verbose=True)

try: 
    import pylab
    csv2timeseries_graphs(directories_dic={'slide'+sep:['Slide',0, 0],
                                           'fixed_wave'+sep:['Fixed Wave',0,0]},
                            output_dir='',#fixed_wave'+sep,
                            base_name='gauge_',
                            plot_numbers='',
                            quantities=['stage','speed','depth'],
                            extra_plot_name='',
                            assess_all_csv_files=True,                            
                            create_latex=False,
                            verbose=True)
except ImportError:
    #ANUGA does not rely on pylab to work 
    print 'must have pylab installed to generate plots'
    

